@@ -9,7 +9,7 @@ from typing import List, Optional
 try:
     import typer
     from rich.console import Console
-    from rich.prompt import Confirm, Prompt
+    from rich.prompt import Confirm
     from rich.syntax import Syntax
     from rich.table import Table
 
@@ -430,7 +430,6 @@ def run_script(
     name: str = typer.Argument(..., help="Name of the script to run"),
     args: List[str] = typer.Argument(None, help="Arguments to pass to the script"),
     session_name: Optional[str] = typer.Option(None, "--session", "-s", help="Run in a specific tmux session"),
-    keep_alive: bool = typer.Option(False, "--keep-alive", "-k", help="Keep session alive after script finishes"),
     direct: bool = typer.Option(False, "--direct", "-d", help="Run directly without tmux session"),
 ):
     """Run a script directly or in a tmux session."""
@@ -485,13 +484,10 @@ def run_script(
 
         command_str = " ".join(base_command)
 
-        if manager.start_session(session_name, command_str, keep_alive):
+        if manager.start_session(session_name, command_str):
             icon = get_script_icon(script_type)
             console.print(f"[green]✅ Started {icon} {script_path.name} in session '{session_name}'[/green]")
 
-            if keep_alive:
-                console.print("[dim]Session will stay alive after script finishes[/dim]")
-
             console.print(f"[blue]View logs with: desto-cli sessions logs {session_name}[/blue]")
             console.print(f"[blue]Attach to session: tmux attach -t {session_name}[/blue]")
         else:
@@ -555,3 +551,29 @@ def copy_script(
     except Exception as e:
         console.print(f"[red]Failed to copy script: {e}[/red]")
         raise typer.Exit(1)
+
+
+@scripts_app.command("chain")
+def chain_scripts(
+    scripts: List[str] = typer.Argument(
+        ..., help="Scripts to run in sequence. Each entry can include arguments, e.g. 'myscript.sh arg1 arg2'. Use quotes for scripts with arguments."
+    ),
+    continue_on_error: bool = typer.Option(False, "--continue-on-error", "-c", help="Continue chain if a script fails"),
+):
+    """
+    Run multiple scripts in sequence (chain). Each script can have its own arguments.
+    Example:
+      desto-cli scripts chain "count_files.sh ./mydir" "other_script.py foo bar"
+    """
+    import shlex
+
+    manager = CLISessionManager()
+    # Parse each script+args as a list
+    scripts_with_args = [shlex.split(entry) for entry in scripts]
+    session_name = manager.start_chain_session(scripts_with_args, continue_on_error=continue_on_error)
+    if session_name:
+        console.print(f"[green]✅ Started chain in session '{session_name}'[/green]")
+        console.print(f"[blue]View logs with: desto-cli sessions logs {session_name}[/blue]")
+    else:
+        console.print("[red]❌ Failed to start chain session[/red]")
+        raise typer.Exit(1)
